==> onos-yang-runtime-2.2.0-sources.jar: org/onosproject/yang/gen/v1/l3vpnsvcext/rev20160730/l3vpnsvcext/extendedcommunity/extendedcommunity/routetargetipv4case/DefaultRouteTargetIpv4.java <==
/*
 * Copyright 2017-present Open Networking Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.l3vpnsvcext.rev20160730.l3vpnsvcext.extendedcommunity.extendedcommunity.routetargetipv4case;

import java.util.BitSet;
import java.util.Objects;
import java.util.StringJoiner;
import org.onosproject.yang.gen.v1.yrtietfinettypes.rev20130715.yrtietfinettypes.Ipv4Address;
import org.onosproject.yang.model.InnerModelObject;

/**
 * Represents the implementation of routeTargetIpv4.
 *
 * <p>
 * valueLeafFlags identify the leafs whose value are explicitly set
 * Applicable in protocol edit and query operation.
 * </p>
 */
public class DefaultRouteTargetIpv4 extends InnerModelObject implements RouteTargetIpv4 {
    protected Ipv4Address globalAdministrator;
    protected int localAdministrator;
    protected BitSet valueLeafFlags = new BitSet();

    @Override
    public Ipv4Address globalAdministrator() {
        return globalAdministrator;
    }

    @Override
    public int localAdministrator() {
        return localAdministrator;
    }

    @Override
    public BitSet valueLeafFlags() {
        return valueLeafFlags;
    }

    @Override
    public void globalAdministrator(Ipv4Address globalAdministrator) {
        valueLeafFlags.set(LeafIdentifier.GLOBALADMINISTRATOR.getLeafIndex());
        this.globalAdministrator = globalAdministrator;
    }

    @Override
    public void localAdministrator(int localAdministrator) {
        valueLeafFlags.set(LeafIdentifier.LOCALADMINISTRATOR.getLeafIndex());
        this.localAdministrator = localAdministrator;
    }

    @Override
    public int hashCode() {
        return Objects.hash(globalAdministrator, localAdministrator, valueLeafFlags);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof DefaultRouteTargetIpv4) {
            DefaultRouteTargetIpv4 other = (DefaultRouteTargetIpv4) obj;
            return
                Objects.equals(globalAdministrator, other.globalAdministrator) &&
                Objects.equals(localAdministrator, other.localAdministrator) &&
                Objects.equals(valueLeafFlags, other.valueLeafFlags);
        }
        return false;
    }

    @Override
    public String toString() {
        return new StringJoiner(", ", getClass().getSimpleName() +"{", "}")
            .add("globalAdministrator=" + globalAdministrator)
            .add("localAdministrator=" + localAdministrator)
            .add("valueLeafFlags=" + valueLeafFlags)
            .toString();
    }


    /**
     * Creates an instance of defaultRouteTargetIpv4.
     */
    public DefaultRouteTargetIpv4() {
    }


    @Override
    public boolean isLeafValueSet(LeafIdentifier leaf) {
        return valueLeafFlags.get(leaf.getLeafIndex());
    }

}

==> onos-yang-runtime-2.3.1-sources.jar: org/onosproject/yang/gen/v1/l3vpnsvcext/rev20160730/l3vpnsvcext/extendedcommunity/extendedcommunity/routetargetipv4case/DefaultRouteTargetIpv4.java <==
/*
 * Copyright 2017-present Open Networking Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.l3vpnsvcext.rev20160730.l3vpnsvcext.extendedcommunity.extendedcommunity.routetargetipv4case;

import java.util.BitSet;
import java.util.Objects;
import java.util.StringJoiner;
import org.onosproject.yang.gen.v1.yrtietfinettypes.rev20130715.yrtietfinettypes.Ipv4Address;
import org.onosproject.yang.model.InnerModelObject;

/**
 * Represents the implementation of routeTargetIpv4.
 *
 * <p>
 * valueLeafFlags identify the leafs whose value are explicitly set
 * Applicable in protocol edit and query operation.
 * </p>
 */
public class DefaultRouteTargetIpv4 extends InnerModelObject implements RouteTargetIpv4 {
    protected Ipv4Address globalAdministrator;
    protected int localAdministrator;
    protected BitSet valueLeafFlags = new BitSet();

    @Override
    public Ipv4Address globalAdministrator() {
        return globalAdministrator;
    }

    @Override
    public int localAdministrator() {
        return localAdministrator;
    }

    @Override
    public BitSet valueLeafFlags() {
        return valueLeafFlags;
    }

    @Override
    public void globalAdministrator(Ipv4Address globalAdministrator) {
        valueLeafFlags.set(LeafIdentifier.GLOBALADMINISTRATOR.getLeafIndex());
        this.globalAdministrator = globalAdministrator;
    }

    @Override
    public void localAdministrator(int localAdministrator) {
        valueLeafFlags.set(LeafIdentifier.LOCALADMINISTRATOR.getLeafIndex());
        this.localAdministrator = localAdministrator;
    }

    @Override
    public int hashCode() {
        return Objects.hash(globalAdministrator, localAdministrator, valueLeafFlags);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof DefaultRouteTargetIpv4) {
            DefaultRouteTargetIpv4 other = (DefaultRouteTargetIpv4) obj;
            return
                Objects.deepEquals(globalAdministrator, other.globalAdministrator) &&
                Objects.deepEquals(localAdministrator, other.localAdministrator) &&
                Objects.deepEquals(valueLeafFlags, other.valueLeafFlags);
        }
        return false;
    }

    @Override
    public String toString() {
        return new StringJoiner(", ", getClass().getSimpleName() +"{", "}")
            .add("globalAdministrator=" + globalAdministrator)
            .add("localAdministrator=" + localAdministrator)
            .add("valueLeafFlags=" + valueLeafFlags)
            .toString();
    }


    /**
     * Creates an instance of defaultRouteTargetIpv4.
     */
    public DefaultRouteTargetIpv4() {
    }


    @Override
    public boolean isLeafValueSet(LeafIdentifier leaf) {
        return valueLeafFlags.get(leaf.getLeafIndex());
    }

}
